@@ -10,18 +10,11 @@ import stat
 import tempfile
 import hashlib
 from time import strftime, localtime
-
-try:
-    import gi
-    gi.require_version("Gtk", "3.0")
-except Exception as detail:
-    print("You do not have a recent version of GTK")
-
-try:
-    import apt
-    from gi.repository import Gtk, Gdk, GdkPixbuf
-except Exception as detail:
-    print("You do not have the required dependencies")
+import apt
+import gi
+gi.require_version("Gtk", "3.0")
+from gi.repository import GdkX11
+from gi.repository import Gtk, Gdk, GdkPixbuf
 
 # i18n
 gettext.install("mintbackup", "/usr/share/linuxmint/locale")
@@ -122,7 +115,6 @@ class MintBackup:
     def __init__(self):
         self.builder = Gtk.Builder()
         self.builder.add_from_file(UI_FILE)
-        self.builder.get_object("main_window").set_icon_from_file("/usr/share/pixmaps/mintbackup/icon.png")
 
         # handle command line filenames
         if len(sys.argv) > 1:
@@ -300,11 +292,6 @@ class MintBackup:
         self.builder.get_object("label_detail3").set_markup("<small>" + _("Restore a previous backup") + "</small>")
         self.builder.get_object("label_detail4").set_markup("<small>" + _("Restore previously installed applications") + "</small>")
 
-        self.builder.get_object("image_backup_data").set_from_file("/usr/share/pixmaps/mintbackup/backup-data.svg")
-        self.builder.get_object("image_restore_data").set_from_file("/usr/share/pixmaps/mintbackup/restore-data.svg")
-        self.builder.get_object("image_backup_software").set_from_file("/usr/share/pixmaps/mintbackup/backup-software.svg")
-        self.builder.get_object("image_restore_software").set_from_file("/usr/share/pixmaps/mintbackup/restore-software.svg")
-
         # i18n - Page 1 (choose backup directories)
         self.builder.get_object("label_title_destination").set_markup("<big><b>" + _("Backup files") + "</b></big>")
         self.builder.get_object("label_caption_destination").set_markup("<i>" + _("Please select a source and a destination for your backup") + "</i>")
